@@ -1,5 +1,5 @@
 /* data.c: Primitive functions for user-facing gzochi data management API
- * Copyright (C) 2015 Julian Graham
+ * Copyright (C) 2016 Julian Graham
  *
  * gzochi is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 
 #include <assert.h>
 #include <glib.h>
-#include <gmp.h>
 #include <libguile.h>
 #include <stddef.h>
 #include <stdlib.h>
@@ -39,15 +38,21 @@ SCM_DEFINE (primitive_create_reference, "primitive-create-reference", 1, 0, 0,
     gzochid_api_ensure_current_application_context ();
   gzochid_scm_location_info *obj_loc = gzochid_scm_location_get (context, obj);
   gzochid_data_managed_reference *reference = gzochid_data_create_reference 
-    (context, &gzochid_scm_location_aware_serialization, obj_loc);
+    (context, &gzochid_scm_location_aware_serialization, obj_loc, NULL);
   SCM ret = SCM_BOOL_F;
 
-  scm_gc_protect_object (obj);
-
-  ret = gzochid_scheme_create_managed_reference (reference);
+  /* The reference returned may be `NULL' if this is a new object and the
+     transaction failed to obtain a lock (transaction timeout, e.g.). In that
+     case, the call to `gzochid_api_check_transaction' will return 
+     non-locally. */
   
+  if (reference != NULL)
+    {  
+      scm_gc_protect_object (obj);
+      ret = gzochid_scheme_create_managed_reference (reference);
+    }
+   
   gzochid_api_check_transaction ();
-
   return ret;
 }
 
@@ -59,16 +64,12 @@ SCM_DEFINE (primitive_dereference, "primitive-dereference", 1, 0, 0, (SCM ref),
     gzochid_api_ensure_current_application_context ();
   gzochid_data_managed_reference *reference = NULL;
   SCM ret = SCM_BOOL_F;
-  mpz_t oid;
-  
-  mpz_init (oid);
 
-  gzochid_scheme_managed_reference_oid (ref, oid);
+  guint64 oid = gzochid_scheme_managed_reference_oid (ref);
 
   reference = gzochid_data_create_reference_to_oid 
     (context, &gzochid_scm_location_aware_serialization, oid);
 
-  mpz_clear (oid);
   gzochid_data_dereference (reference, &err);
 
   if (err == NULL)
@@ -196,36 +197,20 @@ SCM_DEFINE (primitive_remove_binding_x, "primitive-remove-binding!", 1, 0, 0,
     gzochid_api_ensure_current_application_context ();
   char *cname = scm_to_locale_string (name);
   char *prefixed_name = prefix_name (cname);
-  gboolean exists = gzochid_data_binding_exists (context, prefixed_name, &err);
   
-  if (! exists)
-    {
-      SCM cond = SCM_BOOL_F;
-      
-      if (! g_error_matches
-	  (err, GZOCHID_DATA_ERROR, GZOCHID_DATA_ERROR_TRANSACTION))
+  gzochid_data_remove_binding (context, prefixed_name, &err);
 
-	cond = gzochid_scheme_make_name_not_bound_condition (cname);
+  free (prefixed_name);
+
+  if (err != NULL && g_error_matches
+      (err, GZOCHID_DATA_ERROR, GZOCHID_DATA_ERROR_FAILED))
+    {
+      SCM cond = gzochid_scheme_make_name_not_bound_condition (cname);
 
       free (cname);
-      free (prefixed_name);
-      g_error_free (err);
-      
-      if (scm_is_true (cond))
-	gzochid_guile_r6rs_raise (cond);
-    }
-  else
-    {
-      /* `gzochid_data_binding_exists' should never return TRUE if there was
-	 an GError. */
-      
-      assert (err == NULL);
-      
-      gzochid_data_remove_binding (context, prefixed_name, NULL);
-
-      free (cname);
-      free (prefixed_name);
+      gzochid_guile_r6rs_raise (cond);
     }
+  else free (cname);
 
   gzochid_api_check_transaction ();
   return SCM_UNSPECIFIED;
@@ -238,21 +223,31 @@ SCM_DEFINE (primitive_remove_object_x, "primitive-remove-object!", 1, 0, 0,
     gzochid_api_ensure_current_application_context ();
   gzochid_scm_location_info *obj_loc = gzochid_scm_location_get (context, obj);
   gzochid_data_managed_reference *reference = gzochid_data_create_reference 
-    (context, &gzochid_scm_location_aware_serialization, obj_loc);
+    (context, &gzochid_scm_location_aware_serialization, obj_loc, NULL);
 
-  scm_gc_protect_object (obj);    
+  /*
+    The reference returned may be `NULL' if this is a new object and the
+    transaction failed to obtain a lock (transaction timeout, e.g.). 
 
-  gzochid_data_remove_object (reference, NULL);
+    ...But when used properly, this function shouldn't be called with new 
+    objects, only those that were previously dereferenced. So there's little
+    risk of transaction failure, but `gzochid_api_check_transaction' will handle
+    it if necessary. 
+  */
 
+  if (reference != NULL)
+    {
+      scm_gc_protect_object (obj);    
+      gzochid_data_remove_object (reference, NULL);
+    }
+  
   gzochid_api_check_transaction ();
-
   return SCM_UNSPECIFIED;
 }
 
 SCM_DEFINE (primitive_mark_for_write_x, "primitive-mark-for-write!", 1, 0, 0,
 	    (SCM obj), "Mark a managed record that has been modified.")
 {
-  GError *err = NULL;
   gzochid_application_context *context =
     gzochid_api_ensure_current_application_context ();
   gzochid_scm_location_info *obj_loc = gzochid_scm_location_get (context, obj);
@@ -260,7 +255,7 @@ SCM_DEFINE (primitive_mark_for_write_x, "primitive-mark-for-write!", 1, 0, 0,
   scm_gc_protect_object (obj);    
 
   gzochid_data_mark 
-    (context, &gzochid_scm_location_aware_serialization, obj_loc, &err);
+    (context, &gzochid_scm_location_aware_serialization, obj_loc, NULL);
 
   gzochid_api_check_transaction ();
 
