@@ -1,5 +1,5 @@
 /* fsm.h: Prototypes and declarations for fsm.c
- * Copyright (C) 2014 Julian Graham
+ * Copyright (C) 2015 Julian Graham
  *
  * gzochi is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -23,18 +23,7 @@
 typedef void (*gzochid_fsm_enter_function)(int, int, gpointer);
 typedef void (*gzochid_fsm_exit_function)(int, int, gpointer);
 
-typedef struct _gzochid_fsm {
-  char *name;
-  
-  GHashTable *states;
-  GHashTable *transitions;
-
-  int current_state;
-  int started;
-
-  GMutex mutex;
-  GCond cond;
-} gzochid_fsm;
+typedef struct _gzochid_fsm gzochid_fsm;
 
 void gzochid_fsm_on_enter 
 (gzochid_fsm *, int, gzochid_fsm_enter_function, gpointer);
@@ -44,8 +33,24 @@ void gzochid_fsm_on_exit
 gzochid_fsm *gzochid_fsm_new (char *, int, char *);
 void gzochid_fsm_add_state (gzochid_fsm *fsm, int, char *);
 void gzochid_fsm_add_transition (gzochid_fsm *, int, int);
+
+
+/* Start the FSM and transition it to its initial state, invoking any registered
+   `enter' functions in the process. */
+
 void gzochid_fsm_start (gzochid_fsm *);
+
+
+/* Transition the FSM to the specified state, invoking any `exit' functions for
+   its previous state and any `enter' functions for the new state in the 
+   process. 
+
+   It is valid to call this function from within an `enter' or `exit' function;
+   the specified state is "enqueued" as if the re-entrant call were made in tail
+   position. */
+
 void gzochid_fsm_to_state (gzochid_fsm *, int);
+
 void gzochid_fsm_until (gzochid_fsm *, int);
 void gzochid_fsm_free (gzochid_fsm *);
 
