@@ -1,5 +1,5 @@
 /* scheme.c: Supplementary Scheme routines for gzochid
- * Copyright (C) 2015 Julian Graham
+ * Copyright (C) 2016 Julian Graham
  *
  * gzochi is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 
 #include <assert.h>
 #include <glib.h>
-#include <gmp.h>
 #include <gzochi-common.h>
 #include <libguile.h>
 #include <stdarg.h>
@@ -30,7 +29,6 @@
 #include "guile.h"
 #include "gzochid-auth.h"
 #include "io.h"
-#include "log.h"
 #include "reloc.h"
 #include "scheme.h"
 #include "tx.h"
@@ -72,7 +70,8 @@ static SCM scm_make_object_removed_condition;
 static SCM scm_make_name_exists_condition;
 static SCM scm_make_name_not_bound_condition;
 
-GQuark gzochid_scheme_error_quark (void)
+GQuark
+gzochid_scheme_error_quark (void)
 {
   return g_quark_from_static_string ("gzochid-scheme-error-quark");
 }
@@ -140,7 +139,7 @@ gzochid_scheme_invoke_callback (gzochid_application_context *context,
 
 static void 
 scheme_managed_record_serializer (gzochid_application_context *context, SCM arg,
-				  GString *out, GError **err)
+				  GByteArray *out, GError **err)
 {
   unsigned char vec_len_str[4];
   GList *gpd = g_list_append 
@@ -180,23 +179,24 @@ scheme_managed_record_serializer (gzochid_application_context *context, SCM arg,
 
   gzochi_common_io_write_int (vec_len, vec_len_str, 0);
 
-  g_string_append_len (out, (char *) vec_len_str, 4);
-  g_string_append_len (out, (char *) SCM_BYTEVECTOR_CONTENTS (vec), vec_len);
+  g_byte_array_append (out, vec_len_str, 4);
+  g_byte_array_append
+    (out, (unsigned char *) SCM_BYTEVECTOR_CONTENTS (vec), vec_len);
 
   g_list_free (gpd);
 }
 
 static void *
 scheme_managed_record_deserializer (gzochid_application_context *context, 
-				    GString *in, GError **err)
+				    GByteArray *in, GError **err)
 {
-  int vec_len = gzochi_common_io_read_int ((unsigned char *) in->str, 0);
+  int vec_len = gzochi_common_io_read_int (in->data, 0);
   SCM vec = SCM_EOL, port = SCM_EOL, record = SCM_EOL;
   SCM exception_var = scm_make_variable (SCM_UNSPECIFIED);
   GList *args = g_list_append 
     (g_list_append (g_list_append (NULL, "gzochi"), "private"), "data");
 
-  g_string_erase (in, 0, 4);
+  g_byte_array_remove_range (in, 0, 4);
 
   if (vec_len > in->len)
     {
@@ -206,7 +206,7 @@ scheme_managed_record_deserializer (gzochid_application_context *context,
       return SCM_BOOL_F;
     }
   
-  vec = scm_take_u8vector ((unsigned char *) in->str, vec_len);
+  vec = scm_take_u8vector (in->data, vec_len);
   port = scm_open_bytevector_input_port (vec, SCM_BOOL_F);
 
   record = gzochid_scheme_invoke_callback
@@ -218,7 +218,7 @@ scheme_managed_record_deserializer (gzochid_application_context *context,
      exception_var);
 
   g_list_free (args);
-  g_string_erase (in, 0, vec_len);
+  g_byte_array_remove_range (in, 0, vec_len);
   
   if (scm_variable_ref (exception_var) != SCM_UNSPECIFIED)
     {
@@ -235,7 +235,7 @@ scheme_managed_record_deserializer (gzochid_application_context *context,
 	 serializer and deserializer aren't idempotent. */
 
       if (scm_eof_object_p (scm_lookahead_u8 (port)) == SCM_BOOL_F)
-	gzochid_warning ("Deserialization failed to consume all bytes.");
+	g_warning ("Deserialization failed to consume all bytes.");
 
       scm_gc_protect_object (record);
     }
@@ -249,7 +249,7 @@ scheme_serializer_inner (void *data)
   void **ptr = data;
   gzochid_application_context *context = ptr[0];
   SCM task = ptr[1];
-  GString *out = ptr[2];
+  GByteArray *out = ptr[2];
   GError **err = ptr[3];
 
   scheme_managed_record_serializer (context, task, out, err);
@@ -259,7 +259,7 @@ scheme_serializer_inner (void *data)
 
 static void 
 scheme_serializer (gzochid_application_context *context, void *ptr, 
-		   GString *out, GError **err)
+		   GByteArray *out, GError **err)
 {
   void *args[4];
 
@@ -276,14 +276,14 @@ scheme_deserializer_inner (void *data)
 {
   void **ptr = data;
   gzochid_application_context *context = ptr[0];
-  GString *in = ptr[1];
+  GByteArray *in = ptr[1];
   GError **err = ptr[2];
 
   return scheme_managed_record_deserializer (context, in, err);
 }
 
 static void *
-scheme_deserializer (gzochid_application_context *context, GString *in, 
+scheme_deserializer (gzochid_application_context *context, GByteArray *in, 
 		     GError **err)
 {
   void *args[3];
@@ -500,41 +500,31 @@ gzochid_scheme_handler_disconnected (SCM handler)
 
 SCM 
 gzochid_scheme_create_client_session (gzochid_client_session *session, 
-				      mpz_t oid)
+				      guint64 oid)
 {
-  char *oid_str = mpz_get_str (NULL, 16, oid);
-
-  SCM scm_oid = scm_c_locale_stringn_to_number (oid_str, strlen (oid_str), 16);
-  SCM ret = scm_call_2
-    (scm_make_client_session, 
-     scm_from_locale_string (gzochid_auth_identity_name (session->identity)),
-     scm_oid);
+  SCM name = scm_from_locale_string
+    (gzochid_auth_identity_name (gzochid_client_session_identity (session)));
+  
+  SCM scm_oid = scm_from_unsigned_integer (oid);
+  SCM ret = scm_call_2 (scm_make_client_session, name, scm_oid);
 
   scm_gc_protect_object (ret);
-  free (oid_str);
 
   return ret;
 }
 
-void 
-gzochid_scheme_client_session_oid (SCM session, mpz_t oid)
+guint64
+gzochid_scheme_client_session_oid (SCM session)
 {
   SCM scm_oid = scm_call_1 (scm_client_session_oid, session);
-  char *oid_str = scm_to_locale_string 
-    (scm_number_to_string (scm_oid, scm_from_short (16)));
-
-  mpz_set_str (oid, oid_str, 16);
-  free (oid_str);
+  return scm_to_uint64 (scm_oid);
 }
 
 SCM 
 gzochid_scheme_create_managed_reference 
 (gzochid_data_managed_reference *reference)
 {
-  char *oid_str = mpz_get_str (NULL, 16, reference->oid);
-
-  SCM scm_oid = scm_string_to_number 
-    (scm_from_locale_string (oid_str), scm_from_short (16));
+  SCM scm_oid = scm_from_unsigned_integer (reference->oid);
   SCM data = SCM_BOOL_F;
   SCM ret = SCM_BOOL_F;
 
@@ -543,38 +533,30 @@ gzochid_scheme_create_managed_reference
   
   ret = scm_call_2 (scm_make_managed_reference, scm_oid, data);
 
-  free (oid_str);
   scm_gc_protect_object (ret);
 
   return ret;
 }
 
 SCM 
-gzochid_scheme_create_channel (gzochid_channel *channel, mpz_t oid)
+gzochid_scheme_create_channel (gzochid_channel *channel, guint64 oid)
 {
-  char *oid_str = mpz_get_str (NULL, 16, oid);
-  
-  SCM scm_oid = scm_string_to_number
-    (scm_from_locale_string (oid_str), scm_from_short (16));
+  SCM scm_oid = scm_from_unsigned_integer (oid);
   SCM ret = scm_call_2 
-    (scm_make_channel, scm_oid, scm_from_locale_string (channel->name));
+    (scm_make_channel, scm_oid, scm_from_locale_string
+     (gzochid_channel_name (channel)));
 
-  free (oid_str);
   scm_gc_protect_object (ret);
 
   return ret;
 }
 
 SCM 
-gzochid_scheme_create_periodic_task_handle (mpz_t oid)
+gzochid_scheme_create_periodic_task_handle (guint64 oid)
 {
-  char *oid_str = mpz_get_str (NULL, 16, oid);
-  
-  SCM scm_oid = scm_string_to_number
-    (scm_from_locale_string (oid_str), scm_from_short (16));
+  SCM scm_oid = scm_from_unsigned_integer (oid);
   SCM ret = scm_call_1 (scm_make_task_handle, scm_oid);
 
-  free (oid_str);
   scm_gc_protect_object (ret);
 
   return ret;
@@ -654,40 +636,25 @@ initialize_bindings (void *ptr)
   return NULL;
 }
 
-void 
-gzochid_scheme_managed_reference_oid (SCM reference, mpz_t oid)
+guint64
+gzochid_scheme_managed_reference_oid (SCM reference)
 {
   SCM num = scm_call_1 (scm_managed_reference_oid, reference);
-  char *oid_str = scm_to_locale_string 
-    (scm_number_to_string (num, scm_from_short (16)));
-  
-  mpz_set_str (oid, oid_str, 16);
-
-  free (oid_str);
+  return scm_to_uint64 (num);
 }
 
-void 
-gzochid_scheme_channel_oid (SCM channel, mpz_t oid)
+guint64
+gzochid_scheme_channel_oid (SCM channel)
 {
   SCM num = scm_call_1 (scm_channel_oid, channel);
-  char *oid_str = scm_to_locale_string
-    (scm_number_to_string (num, scm_from_short (16)));
-  
-  mpz_set_str (oid, oid_str, 16);
-
-  free (oid_str);
+  return scm_to_uint64 (num);
 }
 
-void 
-gzochid_scheme_task_handle_oid (SCM handle, mpz_t oid)
+guint64
+gzochid_scheme_task_handle_oid (SCM handle)
 {
   SCM num = scm_call_1 (scm_task_handle_oid, handle);
-  char *oid_str = scm_to_locale_string
-    (scm_number_to_string (num, scm_from_short (16)));
-  
-  mpz_set_str (oid, oid_str, 16);
-
-  free (oid_str);
+  return scm_to_uint64 (num);
 }
 
 void 
